summaryrefslogtreecommitdiff
path: root/Modules/CMakeSystemSpecificInformation.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'Modules/CMakeSystemSpecificInformation.cmake')
-rw-r--r--Modules/CMakeSystemSpecificInformation.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/Modules/CMakeSystemSpecificInformation.cmake b/Modules/CMakeSystemSpecificInformation.cmake
index 5aa83b399c..e7a4e6c86f 100644
--- a/Modules/CMakeSystemSpecificInformation.cmake
+++ b/Modules/CMakeSystemSpecificInformation.cmake
@@ -36,10 +36,10 @@ ENDIF(NOT _INCLUDED_SYSTEM_INFO_FILE)
# optionally include a file which can do extra-generator specific things, e.g.
# CMakeEclipseCDT4.cmake asks gcc for the system include dirs for the Eclipse CDT4 generator
IF(CMAKE_EXTRA_GENERATOR)
STRING(REPLACE " " "" _CMAKE_EXTRA_GENERATOR_NO_SPACES ${CMAKE_EXTRA_GENERATOR} )
- INCLUDE("CMake${_CMAKE_EXTRA_GENERATOR_NO_SPACES}" OPTIONAL)
+ INCLUDE("CMakeFind${_CMAKE_EXTRA_GENERATOR_NO_SPACES}" OPTIONAL)
ENDIF(CMAKE_EXTRA_GENERATOR)
@@ -36,10 +36,10 @@ ENDIF(NOT _INCLUDED_SYSTEM_INFO_FILE)
# optionally include a file which can do extra-generator specific things, e.g.
-# CMakeEclipseCDT4.cmake asks gcc for the system include dirs for the Eclipse CDT4 generator
+# CMakeFindEclipseCDT4.cmake asks gcc for the system include dirs for the Eclipse CDT4 generator
IF(CMAKE_EXTRA_GENERATOR)
STRING(REPLACE " " "" _CMAKE_EXTRA_GENERATOR_NO_SPACES ${CMAKE_EXTRA_GENERATOR} )